==> nextcloud-app-deck-1%3A1.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/ast.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "Personal" : "Personal",
    "Finished" : "Finó",
    "Action needed" : "Precísase aición",
    "Later" : "Más sero",
    "Done" : "Fecho",
    "The file was uploaded" : "Xubióse'l ficheru",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El ficheru xubíu perpasa la direutiva de xuba upload_max_filesize en php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El ficheru xubíu perpasa la direutiva \"MAX_FILE_SIZE\" especificada nel formulariu HTML",
    "No file was uploaded" : "Nun se xubieron fichjeros",
    "Missing a temporary folder" : "Falta un direutoriu temporal",
    "Could not write file to disk" : "Nun pudo escribise nel discu'l ficheru",
    "A PHP extension stopped the file upload" : "Una estensión de PHP paró la xuba de ficheros",
    "Cancel" : "Encaboxar",
    "File already exists" : "Yá esiste'l ficheru",
    "Show archived cards" : "Amosar tarxetes archivaes",
    "Details" : "Detalles",
    "Sharing" : "Compartiendo",
    "Tags" : "Etiquetes",
    "Undo" : "Desfacer",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Delete" : "Desaniciar",
    "Edit" : "Editar",
    "Title" : "Títulu",
    "Members" : "Miembros",
    "Description" : "Descripción",
    "Attachments" : "Axuntos",
    "Comments" : "Comentarios",
    "Modified" : "Modificóse'l",
    "Created" : "Creóse",
    "Save" : "Guardar",
    "Reply" : "Rempuesta",
    "Update" : "Anovar",
    "(group)" : "(grupu)",
    "seconds ago" : "hai segundos",
    "Shared with you" : "Shared with you"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3A1.2.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/ast.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "Personal" : "Personal",
    "Finished" : "Finó",
    "Action needed" : "Precísase aición",
    "Later" : "Más sero",
    "Done" : "Fecho",
    "The file was uploaded" : "Xubióse'l ficheru",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El ficheru xubíu perpasa la direutiva de xuba upload_max_filesize en php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El ficheru xubíu perpasa la direutiva \"MAX_FILE_SIZE\" especificada nel formulariu HTML",
    "No file was uploaded" : "Nun se xubieron fichjeros",
    "Missing a temporary folder" : "Falta un direutoriu temporal",
    "Could not write file to disk" : "Nun pudo escribise nel discu'l ficheru",
    "A PHP extension stopped the file upload" : "Una estensión de PHP paró la xuba de ficheros",
    "Cancel" : "Encaboxar",
    "File already exists" : "Yá esiste'l ficheru",
    "Show archived cards" : "Amosar tarxetes archivaes",
    "Details" : "Detalles",
    "Sharing" : "Compartiendo",
    "Tags" : "Etiquetes",
    "Undo" : "Desfacer",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Delete" : "Desaniciar",
    "Edit" : "Editar",
    "Title" : "Títulu",
    "Members" : "Miembros",
    "Attachments" : "Axuntos",
    "Comments" : "Comentarios",
    "Modified" : "Modificóse'l",
    "Created" : "Creóse",
    "Save" : "Guardar",
    "Reply" : "Rempuesta",
    "Update" : "Anovar",
    "Description" : "Descripción",
    "(group)" : "(grupu)",
    "seconds ago" : "hai segundos",
    "Shared with you" : "Shared with you",
    "Today" : "Güei",
    "Tomorrow" : "Mañana",
    "This week" : "Esta selmana"
},
"nplurals=2; plural=(n != 1);");
